**this file will be overwriten! **

 - Write documentation describing your app, files starting __ are ignored.

 - or add to `links.json`

## Settings

 - *save_dir*: None

 - *sample*: None

 - *data_fname_format*: None

 - *propose_from_file*: right click on setting widget to see and load value from a file

 - *dark_mode*: <i>Unknown</i> let the operating system decide

